{% extends "base.html" %}
{% block content %}

<div>
    <strong>freetar</strong> is an open source alternative front-end to ultimate-guitar.com<br>
    Running version v{{ version }}<br>
    License: <a href="https://github.com/kmille/freetar/blob/main/LICENSE">GPL 3.0</a><br>
    Source Code: <a href="https://github.com/kmille/freetar">https://github.com/kmille/freetar</a><br>
    Any problems? Wishes? Create an <a href="https://github.com/kmille/freetar/issues/new">issue</a>.<br>
</div>

{% endblock %}
